// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KHEALTHCERTIFICATE_VERSION_H
#define KHEALTHCERTIFICATE_VERSION_H

#define KHEALTHCERTIFICATE_VERSION_STRING "23.01.00"
#define KHEALTHCERTIFICATE_VERSION_MAJOR 23
#define KHEALTHCERTIFICATE_VERSION_MINOR 1
#define KHEALTHCERTIFICATE_VERSION_PATCH 0
#define KHEALTHCERTIFICATE_VERSION ((23<<16)|(1<<8)|(0))

#endif
